m4us.core — Message For You Sir! v0.2.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.2.1 documentation »
- API Documentation »

# `m4us.core`

Provides all the core contructs for this project.

The core is sufficient to create, group, link and run coroutines. It also contains a few of basic pre-made coroutines. Most other pre-made coroutines and enhancements are in modules outside of this core package.

Modules

- `m4us.core.api`
- `m4us.core.components`
- `m4us.core.containers`
- `m4us.core.coroutines`
- `m4us.core.exceptions`
- `m4us.core.interfaces`
- `m4us.core.messages`
- `m4us.core.postoffices`
- `m4us.core.schedulers`
- `m4us.core.utils`

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.2.1 documentation »
- API Documentation »